/****************************************************************
 *								*
 * Copyright (c) 2001-2023 Fidelity National Information	*
 * Services, Inc. and/or its subsidiaries. All rights reserved.	*
 *								*
 *	This source code contains the intellectual property	*
 *	of its copyright holder(s), and is made available	*
 *	under a license.  If you do not know the terms of	*
 *	the license, please stop and do not read further.	*
 *								*
 ****************************************************************/

#ifndef MM_READ_INCLUDED
#define MM_READ_INCLUDED

sm_uc_ptr_t mm_read(block_id blk, boolean_t blk_free);

#endif /* MM_READ_INCLUDED */
